@@ -15,7 +15,6 @@ class CmdCheckout(base.BaseCommand):
             return return_code
 
         repo_git = scm.Scm(root_dir=mir_root, scm_executable='git')
-        repo_dvc = scm.Scm(root_dir=mir_root, scm_executable='dvc')
 
         # git options
         cmd_opts = []
@@ -27,10 +26,6 @@ class CmdCheckout(base.BaseCommand):
         if output_str:
             logging.info("\n%s" % output_str)
 
-        output_str = repo_dvc.checkout("-f")
-        if output_str:
-            logging.info("\n%s" % output_str)
-
         return MirCode.RC_OK
 
     def run(self) -> int:
