@@ -48,8 +48,7 @@ class CmdLog(base.BaseCommand):
                                     dog=self.args.dog)
 
 
-def bind_to_subparsers(subparsers: argparse._SubParsersAction,
-                       parent_parser: argparse.ArgumentParser) -> None:
+def bind_to_subparsers(subparsers: argparse._SubParsersAction, parent_parser: argparse.ArgumentParser) -> None:
     log_arg_parser = subparsers.add_parser("log",
                                            parents=[parent_parser],
                                            description="use this command to show mir repo log",
