@@ -10,14 +10,14 @@ def Scm(root_dir: str, scm_executable: str = None) -> CmdScm:
         path.
         Args:
             root_dir (str): path to a root directory of the repo.
-            scm_excutable(str): one of "dvc" or "git".
+            scm_excutable(str): "git".
         Returns:
             mir.scm.cmd.BaseScm: SCM instance.
         """
 
-    if scm_executable not in ["dvc", "git"]:
+    if scm_executable not in ["git"]:
         raise MirRuntimeError(error_code=MirCode.RC_CMD_INVALID_ARGS,
-                              error_message=f"args error: expected dvc or git, not {scm_executable}")
+                              error_message=f"args error: expected git, not {scm_executable}")
     if not os.path.exists(root_dir):
         os.makedirs(root_dir)
     if not os.path.isdir(root_dir):
